==> stringi_0.3-1.tar.gz: stringi/R/internal_test.R <==
## This file is part of the 'stringi' package for R.
## Copyright (c) 2013-2014, Marek Gagolewski and Bartek Tartanus
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions are met:
##
## 1. Redistributions of source code must retain the above copyright notice,
## this list of conditions and the following disclaimer.
##
## 2. Redistributions in binary form must reproduce the above copyright notice,
## this list of conditions and the following disclaimer in the documentation
## and/or other materials provided with the distribution.
##
## 3. Neither the name of the copyright holder nor the names of its
## contributors may be used to endorse or promote products derived from
## this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
## SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
## PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
## OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
## WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
## OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
## EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


# Check R encoding marking [internal, DEBUG only]
#
# This is an internal function (no-export & no-manual) - test how R marks
# ASCII/LATIN1/UTF8/BYTES encodings (see also \code{?Encoding}).
#
# Results are printed on STDERR
#
# @param str character vector
# @return who cares
.stri_test_Rmark <- function(str) {
   invisible(.Call("stri_test_Rmark", str, PACKAGE="stringi"))
}


# For testing StriContainerUTF16's performance [internal, DEBUG only]
#
# @param str character vector
# @return who cares
.stri_test_StriContainerUTF16 <- function(str) {
   .Call("stri_test_UnicodeContainer16", str, PACKAGE="stringi")
}


# For testing StriContainerUTF8's performance [internal, DEBUG only]
#
# @param str character vector
# @return who cares
.stri_test_StriContainerUTF8 <- function(str) {
   .Call("stri_test_UnicodeContainer8", str, PACKAGE="stringi")
}


# For testing .Call performance [internal, DEBUG only]
#
# @param str some object
# @return \code{str}
.stri_test_returnasis <- function(x) {
   .Call("stri_test_returnasis", x, PACKAGE="stringi")
}

==> stringi_0.4-1.tar.gz: stringi/R/internal_test.R <==
## This file is part of the 'stringi' package for R.
## Copyright (c) 2013-2014, Marek Gagolewski and Bartek Tartanus
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions are met:
##
## 1. Redistributions of source code must retain the above copyright notice,
## this list of conditions and the following disclaimer.
##
## 2. Redistributions in binary form must reproduce the above copyright notice,
## this list of conditions and the following disclaimer in the documentation
## and/or other materials provided with the distribution.
##
## 3. Neither the name of the copyright holder nor the names of its
## contributors may be used to endorse or promote products derived from
## this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
## SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
## PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
## OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
## WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
## OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
## EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


# Check R encoding marking [internal, DEBUG only]
#
# This is an internal function (no-export & no-manual) - test how R marks
# ASCII/LATIN1/UTF8/BYTES encodings (see also \code{?Encoding}).
#
# Results are printed on STDERR
#
# @param str character vector
# @return who cares
.stri_test_Rmark <- function(str) {
   invisible(.Call(C_stri_test_Rmark, str))
}


# For testing StriContainerUTF16's performance [internal, DEBUG only]
#
# @param str character vector
# @return who cares
.stri_test_StriContainerUTF16 <- function(str) {
   .Call(C_stri_test_UnicodeContainer16, str)
}


# For testing StriContainerUTF8's performance [internal, DEBUG only]
#
# @param str character vector
# @return who cares
.stri_test_StriContainerUTF8 <- function(str) {
   .Call(C_stri_test_UnicodeContainer8, str)
}


# For testing .Call performance [internal, DEBUG only]
#
# @param str some object
# @return \code{str}
.stri_test_returnasis <- function(x) {
   .Call(C_stri_test_returnasis, x)
}
